/**
 * The <code>Key</code> class provides a container
 * for the data held in a node of the Option PDAG
 * <p>
 * This includes member variables for the stock price,
 * auxilliary process, time, and option value.
 *
 * @author  Somesh Jha
 * @author  Jeff Stephenson
 */


import java.io.*;

public class Key implements KeyInterface
{
    /**
     * The (int) time value 
     */
    public int t;

    /**
     * The (double) stock price 
     */
    public double stock_price;

    /**
     * The (double) aux process value 
     */
    public double aux_process;

    /**
     * The (double) option value 
     */
    public double option_value;

    /**
     * Constructs a Key object, and sets the initial value
     * of the time, stock price,and aux process.
     *
     * @param   t			the (int) time value
     * @param   s			the (double) stock price
     * @param   p			the (double) aux process value
     */
    public Key(int t, double s, double p) 
    {
        this.t = t;
        stock_price = s;
        aux_process = p;
    }

    /**
     * Prints the data in this Key object
     *
     */
    public void printKey() 
    {
        System.out.print("time: "); 
        System.out.print(t);
        System.out.print(" stock_price:  "); 
        System.out.print(stock_price);
        System.out.print(" aux_process:  "); 
        System.out.print(aux_process);
        System.out.print(" option_value: "); 
        System.out.print(option_value);
        System.out.println();
    }


    /**
     * Compares Key objects
     *
     * @param   key		the (Key) to compare against
     */
    public boolean isEqual(KeyInterface key) 
    {
        Key aKey = (Key) key;

        if (aKey.t == t && 
            aKey.stock_price == stock_price &&
            aKey.aux_process == aux_process)
        {
            return(true);
        }

        return(false);
    }


    /**
     * Checks whether this key is less than the given key
     *
     * @param   k			the (KeyInterface) to the comparison object
     */

    public boolean isLessThan(KeyInterface key)
    {
        Key aKey = (Key) key;


        boolean lessThan = false;

        if (stock_price < aKey.stock_price)
        {
            lessThan =  true;
        }
        else
        {
            if (stock_price == aKey.stock_price)
            {
                if (aux_process < aKey.aux_process)
                {
                    lessThan = true;
                }
                else
                {
                    if (aux_process == aKey.aux_process)
                    {
                        if (option_value < aKey.option_value)
                        {
                            lessThan = true;
                        }
                    }
      
                }
            }
        }

        return lessThan;

    }

} 
    
      
    


